#line 1 "Engine/csound_prelex.c"

#line 3 "Engine/csound_prelex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define csound_pre_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer csound_pre_create_buffer
#endif

#ifdef yy_delete_buffer
#define csound_pre_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer csound_pre_delete_buffer
#endif

#ifdef yy_scan_buffer
#define csound_pre_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer csound_pre_scan_buffer
#endif

#ifdef yy_scan_string
#define csound_pre_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string csound_pre_scan_string
#endif

#ifdef yy_scan_bytes
#define csound_pre_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes csound_pre_scan_bytes
#endif

#ifdef yy_init_buffer
#define csound_pre_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer csound_pre_init_buffer
#endif

#ifdef yy_flush_buffer
#define csound_pre_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer csound_pre_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define csound_pre_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state csound_pre_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define csound_pre_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer csound_pre_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define csound_prepush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state csound_prepush_buffer_state
#endif

#ifdef yypop_buffer_state
#define csound_prepop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state csound_prepop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define csound_preensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack csound_preensure_buffer_stack
#endif

#ifdef yylex
#define csound_prelex_ALREADY_DEFINED
#else
#define yylex csound_prelex
#endif

#ifdef yyrestart
#define csound_prerestart_ALREADY_DEFINED
#else
#define yyrestart csound_prerestart
#endif

#ifdef yylex_init
#define csound_prelex_init_ALREADY_DEFINED
#else
#define yylex_init csound_prelex_init
#endif

#ifdef yylex_init_extra
#define csound_prelex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra csound_prelex_init_extra
#endif

#ifdef yylex_destroy
#define csound_prelex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy csound_prelex_destroy
#endif

#ifdef yyget_debug
#define csound_preget_debug_ALREADY_DEFINED
#else
#define yyget_debug csound_preget_debug
#endif

#ifdef yyset_debug
#define csound_preset_debug_ALREADY_DEFINED
#else
#define yyset_debug csound_preset_debug
#endif

#ifdef yyget_extra
#define csound_preget_extra_ALREADY_DEFINED
#else
#define yyget_extra csound_preget_extra
#endif

#ifdef yyset_extra
#define csound_preset_extra_ALREADY_DEFINED
#else
#define yyset_extra csound_preset_extra
#endif

#ifdef yyget_in
#define csound_preget_in_ALREADY_DEFINED
#else
#define yyget_in csound_preget_in
#endif

#ifdef yyset_in
#define csound_preset_in_ALREADY_DEFINED
#else
#define yyset_in csound_preset_in
#endif

#ifdef yyget_out
#define csound_preget_out_ALREADY_DEFINED
#else
#define yyget_out csound_preget_out
#endif

#ifdef yyset_out
#define csound_preset_out_ALREADY_DEFINED
#else
#define yyset_out csound_preset_out
#endif

#ifdef yyget_leng
#define csound_preget_leng_ALREADY_DEFINED
#else
#define yyget_leng csound_preget_leng
#endif

#ifdef yyget_text
#define csound_preget_text_ALREADY_DEFINED
#else
#define yyget_text csound_preget_text
#endif

#ifdef yyget_lineno
#define csound_preget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno csound_preget_lineno
#endif

#ifdef yyset_lineno
#define csound_preset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno csound_preset_lineno
#endif

#ifdef yyget_column
#define csound_preget_column_ALREADY_DEFINED
#else
#define yyget_column csound_preget_column
#endif

#ifdef yyset_column
#define csound_preset_column_ALREADY_DEFINED
#else
#define yyset_column csound_preset_column
#endif

#ifdef yywrap
#define csound_prewrap_ALREADY_DEFINED
#else
#define yywrap csound_prewrap
#endif

#ifdef yyalloc
#define csound_prealloc_ALREADY_DEFINED
#else
#define yyalloc csound_prealloc
#endif

#ifdef yyrealloc
#define csound_prerealloc_ALREADY_DEFINED
#else
#define yyrealloc csound_prerealloc
#endif

#ifdef yyfree
#define csound_prefree_ALREADY_DEFINED
#else
#define yyfree csound_prefree
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define csound_prewrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 102
#define YY_END_OF_BUFFER 103
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[448] =
    {   0,
        0,    0,   14,   14,   18,   18,   23,   23,   26,   26,
      103,  101,    3,    3,    8,  101,  101,  101,    5,   30,
      101,   30,   30,   30,   30,   30,   30,   30,   30,   30,
       30,   30,   30,   30,   30,   30,   30,   30,  101,   15,
       14,  102,   21,   18,   20,   23,   24,   26,   27,    3,
        0,    0,    0,    0,    0,    0,   10,    0,    6,    4,
       30,    7,    7,    2,    2,    7,    0,   72,   30,   30,
       30,   30,   30,   30,   30,   30,   30,   30,   30,    0,
       62,   30,    0,   63,   30,   30,   30,   30,    0,   98,
       30,   30,   30,   30,   30,   30,   30,   30,   30,   30,

       30,   30,    0,   14,   18,   19,   20,   23,   24,   26,
       27,    0,    0,    0,    0,    0,    0,    0,    0,   11,
       10,   10,    0,    2,    0,    0,    2,   30,   30,   30,
       30,   30,   30,   30,    0,   97,   30,   30,   30,   30,
       30,   30,   30,   30,   30,   30,   30,   30,   30,   30,
       30,   30,   30,   30,   30,   30,   30,   30,   30,   30,
       30,   30,   30,   30,   30,   30,   30,   30,   30,   30,
        0,    0,    1,    0,    0,   29,    0,    0,    0,    0,
        0,    2,    0,   38,   30,   30,   30,   30,    0,   43,
       30,   30,   30,   30,   30,   30,   30,    0,   39,   30,

       30,   30,   30,   30,   30,   30,    0,   31,    0,   40,
       30,   30,   30,    0,   90,   30,   30,   30,   30,   30,
       30,   30,   30,   30,   30,    0,   36,   30,   30,    0,
       42,   30,   30,   30,    0,   44,   30,   30,    0,   73,
        0,   74,   30,   30,   30,   30,   30,   30,    0,   75,
        0,   76,    0,   77,    0,   78,    0,   79,    0,   80,
        0,   81,    0,   82,    0,   89,    9,    0,    0,   29,
       29,    0,   16,    0,    0,    0,   30,   30,    0,   35,
        0,   91,    0,   51,   30,   30,   30,   30,   30,   30,
       30,    0,   32,   30,   30,   30,   30,    0,   59,   30,

        0,   49,   30,   30,   30,   30,   30,   30,   30,   30,
       30,    0,   99,    0,  100,   30,   30,    0,   50,   30,
        0,   41,    0,   52,   30,    0,   83,    0,   84,    0,
       85,    0,   86,    0,   87,    0,   88,    0,    0,   28,
        0,   29,   29,   25,    0,   22,    0,   53,   30,    0,
       37,   30,   30,   30,   30,    0,   55,   30,    0,   34,
       30,    0,   57,    0,   58,   30,    0,   48,   30,    0,
       69,   30,   30,   30,   30,   30,   30,   30,    0,   33,
       30,   30,   30,   17,    0,    0,   30,    0,   46,   30,
        0,   64,    0,   66,   30,   30,   30,   30,    0,   92,

        0,   68,   30,    0,   65,   30,    0,   67,   30,   30,
        0,   45,    0,   47,   13,    0,   54,   30,    0,   56,
        0,   61,    0,   60,    0,   71,   30,   30,   30,   30,
        0,   30,   30,   30,    0,   70,    0,   93,    0,    0,
       94,    0,   95,    0,   96,   12,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    5,    6,    7,    1,    1,    1,    8,
        1,    9,    1,    1,    1,   10,   11,   12,   13,   14,
       15,   16,   17,   18,   19,   20,   21,    1,   22,    1,
        1,    1,    1,    1,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
        1,   24,    1,    1,   23,   25,   26,   27,   28,   29,

       30,   31,   32,   33,   34,   23,   35,   36,   37,   38,
       39,   40,   41,   42,   43,   44,   45,   46,   47,   48,
       23,   23,   49,    1,   50,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[51] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    3,    1,    4,
        1,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    1,    6,    1,    7,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    1,    1
    } ;

static const flex_int16_t yy_base[460] =
    {   0,
        0,    0,   49,   51,   54,    0,  104,    0,  153,    0,
      798,  799,  799,  794,  799,  200,  771,  147,  799,    0,
      201,  205,  761,  127,  767,  745,  126,  170,  157,  753,
      121,  763,  207,  135,  136,  180,  185,  748,  740,  799,
      786,  799,  799,  785,  778,  783,    0,  782,    0,  799,
      214,  777,  752,  188,  187,  743,  153,  755,  799,  799,
        0,  799,  235,  799,  776,  216,  169,  799,  735,  737,
      734,  193,  732,  731,  239,  733,  733,  745,  212,  220,
      799,  726,  242,  799,  737,  724,  741,  722,  250,  799,
      732,  717,  725,  736,  732,  715,  722,  720,  715,  718,

      259,  726,  704,  751,  750,  799,  743,  748,    0,  747,
        0,  745,  716,  703,  716,  710,  222,  715,  713,  799,
      733,  246,  259,  737,  263,  265,  279,  251,  710,  700,
      701,  692,  282,  248,  284,  799,  698,  691,  287,  694,
      704,  258,  263,  689,  292,  294,  297,  693,  283,  267,
      690,  697,  689,  310,  688,  691,  311,  680,  320,  322,
      353,  323,  324,  325,  327,  332,  334,  335,  339,  344,
      673,  672,  799,  687,  690,  337,  675,  688,  688,  680,
      685,  799,  348,  799,  687,  684,  349,  356,  370,  799,
      371,  674,  677,  682,  681,  668,  681,  372,  799,  664,

      373,  667,  661,  665,  658,  374,  375,  799,  382,  799,
      689,  383,  656,  384,  799,  659,  652,  657,  662,  667,
      660,  665,  661,  385,  386,  387,  799,  662,  646,  394,
      799,  395,  651,  396,  397,  799,  398,  650,  399,  799,
      406,  799,  407,  408,  409,  410,  411,  418,  419,  799,
      420,  799,  421,  799,  422,  799,  423,  799,  430,  799,
      431,  799,  432,  799,  433,  799,  799,  649,  434,  295,
        0,  655,  799,  654,  639,  652,  440,  441,  442,  799,
      443,  799,  444,  799,  636,  652,  636,  646,  445,  641,
      452,  453,  799,  641,  455,  456,  642,  457,  799,  460,

      464,  799,  628,  465,  644,  630,  643,  638,  641,  625,
      624,  467,  799,  468,  799,  472,  628,  475,  799,  620,
      476,  799,  477,  799,  619,  479,  799,  480,  799,  484,
      799,  487,  799,  488,  799,  489,  799,  634,  491,  799,
      660,    0,  496,  799,  633,  799,  497,  799,  618,  498,
      799,  499,  626,  500,  501,  502,  799,  619,  509,  799,
      615,  512,  799,  513,  799,  620,  514,  799,  605,  517,
      799,  521,  522,  583,  524,  562,  525,  548,  526,  799,
      474,  529,  533,  799,  360,  332,  534,  536,  799,  322,
      537,  799,  538,  799,  541,  545,  546,  548,  549,  799,

      550,  799,  311,  553,  799,  310,  557,  799,  299,  284,
      558,  799,  560,  799,  267,  561,  799,  263,  562,  799,
      565,  799,  569,  799,  570,  799,  226,  211,  572,  573,
      189,  574,  577,  581,  582,  799,  584,  799,  175,  585,
      799,  586,  799,  589,  799,  799,  799,  597,  599,  602,
      608,  613,  615,  617,  621,  628,  635,  642,  649
    } ;

static const flex_int16_t yy_def[460] =
    {   0,
      447,    1,  448,  448,  447,    5,  447,    7,    7,    9,
      447,  447,  447,  447,  447,  447,  449,  447,  447,  450,
      451,  450,  450,  450,  450,  450,  450,  450,  450,  450,
      450,  450,  450,  450,  450,  450,  450,  450,  447,  447,
      447,  447,  447,  447,  452,  447,  453,  447,  454,  447,
      447,  447,  447,  447,  447,  447,  455,  449,  447,  447,
      450,  447,  447,  447,  447,  456,  447,  447,  450,  450,
      450,  450,  450,  450,  450,  450,  450,  450,  450,  447,
      447,  450,  447,  447,  450,  450,  450,  450,  447,  447,
      450,  450,  450,  450,  450,  450,  450,  450,  450,  450,

      450,  450,  457,  447,  447,  447,  452,  447,  453,  447,
      454,  447,  447,  447,  447,  447,  447,  447,  447,  447,
      447,  455,  447,  447,  456,  456,  456,  450,  450,  450,
      450,  450,  450,  450,  447,  447,  450,  450,  450,  450,
      450,  450,  450,  450,  450,  450,  450,  450,  450,  450,
      450,  450,  450,  450,  450,  450,  450,  450,  450,  450,
      450,  450,  450,  450,  450,  450,  450,  450,  450,  450,
      457,  457,  447,  447,  447,  447,  447,  447,  447,  447,
      447,  447,  447,  447,  450,  450,  450,  450,  447,  447,
      450,  450,  450,  450,  450,  450,  450,  447,  447,  450,

      450,  450,  450,  450,  450,  450,  447,  447,  447,  447,
      450,  450,  450,  447,  447,  450,  450,  450,  450,  450,
      450,  450,  450,  450,  450,  447,  447,  450,  450,  447,
      447,  450,  450,  450,  447,  447,  450,  450,  447,  447,
      447,  447,  450,  450,  450,  450,  450,  450,  447,  447,
      447,  447,  447,  447,  447,  447,  447,  447,  447,  447,
      447,  447,  447,  447,  447,  447,  447,  447,  447,  447,
      458,  447,  447,  447,  447,  447,  450,  450,  447,  447,
      447,  447,  447,  447,  450,  450,  450,  450,  450,  450,
      450,  447,  447,  450,  450,  450,  450,  447,  447,  450,

      447,  447,  450,  450,  450,  450,  450,  450,  450,  450,
      450,  447,  447,  447,  447,  450,  450,  447,  447,  450,
      447,  447,  447,  447,  450,  447,  447,  447,  447,  447,
      447,  447,  447,  447,  447,  447,  447,  447,  447,  447,
      459,  458,  447,  447,  447,  447,  447,  447,  450,  447,
      447,  450,  450,  450,  450,  447,  447,  450,  447,  447,
      450,  447,  447,  447,  447,  450,  447,  447,  450,  447,
      447,  450,  450,  450,  450,  450,  450,  450,  447,  447,
      450,  450,  450,  447,  459,  447,  450,  447,  447,  450,
      447,  447,  447,  447,  450,  450,  450,  450,  447,  447,

      447,  447,  450,  447,  447,  450,  447,  447,  450,  450,
      447,  447,  447,  447,  447,  447,  447,  450,  447,  447,
      447,  447,  447,  447,  447,  447,  450,  450,  450,  450,
      447,  450,  450,  450,  447,  447,  447,  447,  447,  447,
      447,  447,  447,  447,  447,  447,    0,  447,  447,  447,
      447,  447,  447,  447,  447,  447,  447,  447,  447
    } ;

static const flex_int16_t yy_nxt[850] =
    {   0,
       12,   12,   13,   14,   15,   16,   17,   12,   12,   12,
       18,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   19,   20,   21,   12,   22,   23,   24,   25,   26,
       27,   20,   20,   28,   29,   30,   20,   31,   32,   33,
       34,   35,   36,   37,   38,   20,   20,   20,   39,   12,
       41,   42,   41,   42,   43,   44,   42,   43,   43,   43,
       43,   43,   43,   43,   43,   43,   43,   43,   43,   43,
       43,   43,   43,   43,   43,   43,   45,   43,   43,   45,
       45,   45,   45,   45,   45,   45,   45,   45,   45,   45,
       45,   45,   45,   45,   45,   45,   45,   45,   45,   45,

       45,   45,   43,   43,   42,   46,   42,   42,   42,   42,
       42,   42,   42,   42,   42,   42,   42,   42,   42,   42,
       42,   42,   42,   42,   42,   42,   47,   42,   42,   47,
       47,   47,   47,   47,   47,   47,   47,   47,   47,   47,
       47,   47,   47,   47,   47,   47,   47,   47,   47,   47,
       47,   47,   42,   42,   48,   59,   72,   60,   83,   86,
      120,   77,  121,   87,   84,   73,   74,   78,   93,   79,
       67,   80,   94,   95,   96,   49,   68,   81,   49,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   49,

       49,   51,   63,   64,   65,   52,   67,   82,   89,   97,
      100,  101,   68,   98,   90,   51,  446,  117,   64,  127,
       99,   80,   66,  114,  118,  115,  131,   81,   53,   54,
      132,   69,  439,   55,   91,  116,  123,   64,  124,  142,
      135,   70,   53,   83,   56,   92,  136,  143,  434,   84,
      178,   89,  183,  120,  144,  121,  125,   90,  184,  179,
      123,   64,  124,  433,  137,   64,  127,   64,  127,  138,
      160,  161,  162,  163,  164,  165,  166,  167,  168,  169,
      125,  182,  127,  189,  193,  135,  194,  195,  198,  190,
      202,  136,  204,  207,  199,  209,  270,  203,  214,  208,

      432,  210,  205,  221,  215,  222,  211,  212,  217,  431,
      218,  226,  230,  430,  191,  192,  271,  227,  231,  219,
      213,  235,  220,  239,  249,  251,  253,  236,  255,  240,
      250,  252,  254,  257,  256,  259,  261,  429,  270,  258,
      263,  260,  262,  232,  233,  265,  264,  428,  427,  183,
      279,  266,  237,  238,  241,  184,  280,  281,  271,  418,
      242,  415,  340,  282,  243,  244,  245,  246,  247,  248,
      272,  189,  283,  198,  292,  298,  207,  190,  284,  199,
      293,  299,  208,  209,  301,  214,  312,  314,  226,  210,
      302,  215,  313,  315,  227,  230,  318,  321,  235,  323,

      239,  231,  319,  322,  236,  324,  240,  241,  326,  328,
      330,  332,  334,  242,  327,  329,  331,  333,  335,  336,
      249,  251,  253,  255,  257,  337,  250,  252,  254,  256,
      258,  259,  261,  263,  265,  339,  340,  260,  262,  264,
      266,  347,  350,  279,  281,  283,  356,  348,  351,  280,
      282,  284,  357,  359,  292,  341,  362,  364,  298,  360,
      293,  367,  363,  365,  299,  301,  370,  368,  312,  314,
      349,  302,  371,  379,  313,  315,  318,  321,  323,  380,
      326,  328,  319,  322,  324,  330,  327,  329,  332,  334,
      336,  331,  339,  340,  333,  335,  337,  270,  347,  350,

      388,  391,  393,  356,  348,  351,  389,  392,  394,  357,
      359,  410,  341,  362,  364,  367,  360,  271,  370,  363,
      365,  368,  399,  401,  371,  404,  407,  379,  400,  402,
      411,  405,  408,  380,  413,  416,  412,  388,  391,  393,
      414,  417,  419,  389,  392,  394,  421,  423,  420,  425,
      399,  401,  422,  424,  404,  426,  400,  402,  407,  411,
      405,  413,  416,  419,  408,  412,  421,  414,  417,  420,
      423,  425,  422,  435,  437,  440,  424,  426,  442,  436,
      438,  441,  444,  435,  443,  437,  440,  442,  445,  436,
      444,  438,  441,  443,  409,  406,  445,   40,   40,   40,

       40,   40,   40,   40,   57,   57,   61,   61,   62,   62,
       62,   62,   62,   62,   62,  107,  403,  107,  107,  109,
      109,  111,  111,  122,  122,  122,  122,  122,  126,  126,
      126,  126,  126,  126,  126,  171,  171,  171,  171,  171,
      171,  171,  342,  398,  342,  342,  342,  342,  342,  385,
      385,  385,  385,  385,  385,  385,  397,  396,  395,  390,
      387,  386,  340,  384,  383,  382,  381,  378,  377,  376,
      375,  374,  373,  372,  369,  366,  361,  358,  355,  354,
      353,  352,  346,  345,  344,  343,  338,  325,  320,  317,
      316,  311,  310,  309,  308,  307,  306,  305,  304,  303,

      300,  297,  296,  295,  294,  291,  290,  289,  288,  287,
      286,  285,  278,  277,  276,  275,  178,  274,  273,  269,
      268,  267,  172,  234,  229,  228,  225,  224,  223,  216,
      206,  201,  200,  197,  196,  188,  187,  186,  185,   64,
      120,  181,  180,  177,  176,  175,  174,  173,  110,  108,
      106,  105,  104,  172,  170,  159,  158,  157,  156,  155,
      154,  153,  152,  151,  150,  149,  148,  147,  146,  145,
      141,  140,  139,  134,  133,  130,  129,  128,   64,  447,
      119,  113,  112,  110,  108,  106,  105,  104,  103,  102,
       88,   85,   76,   75,   71,   58,   50,  447,   11,  447,

      447,  447,  447,  447,  447,  447,  447,  447,  447,  447,
      447,  447,  447,  447,  447,  447,  447,  447,  447,  447,
      447,  447,  447,  447,  447,  447,  447,  447,  447,  447,
      447,  447,  447,  447,  447,  447,  447,  447,  447,  447,
      447,  447,  447,  447,  447,  447,  447,  447,  447
    } ;

static const flex_int16_t yy_chk[850] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        3,    3,    4,    4,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,

        5,    5,    5,    5,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    9,   18,   24,   18,   29,   31,
       57,   27,   57,   31,   29,   24,   24,   27,   34,   27,
       67,   28,   34,   35,   35,    9,   67,   28,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,

        9,   16,   21,   21,   21,   16,   22,   28,   33,   36,
       37,   37,   22,   36,   33,   51,  439,   55,   66,   66,
       36,   80,   21,   54,   55,   54,   72,   80,   16,   16,
       72,   22,  431,   16,   33,   54,   63,   63,   63,   79,
       75,   22,   51,   83,   16,   33,   75,   79,  428,   83,
      117,   89,  128,  122,   79,  122,   63,   89,  128,  117,
      123,  123,  123,  427,   75,  125,  125,  126,  126,   75,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      123,  127,  127,  133,  134,  135,  134,  134,  139,  133,
      142,  135,  143,  145,  139,  146,  270,  142,  147,  145,

      418,  146,  143,  150,  147,  150,  146,  146,  149,  415,
      149,  154,  157,  410,  133,  133,  270,  154,  157,  149,
      146,  159,  149,  160,  162,  163,  164,  159,  165,  160,
      162,  163,  164,  166,  165,  167,  168,  409,  176,  166,
      169,  167,  168,  157,  157,  170,  169,  406,  403,  183,
      187,  170,  159,  159,  161,  183,  187,  188,  176,  390,
      161,  386,  385,  188,  161,  161,  161,  161,  161,  161,
      176,  189,  191,  198,  201,  206,  207,  189,  191,  198,
      201,  206,  207,  209,  212,  214,  224,  225,  226,  209,
      212,  214,  224,  225,  226,  230,  232,  234,  235,  237,

      239,  230,  232,  234,  235,  237,  239,  241,  243,  244,
      245,  246,  247,  241,  243,  244,  245,  246,  247,  248,
      249,  251,  253,  255,  257,  248,  249,  251,  253,  255,
      257,  259,  261,  263,  265,  269,  269,  259,  261,  263,
      265,  277,  278,  279,  281,  283,  289,  277,  278,  279,
      281,  283,  289,  291,  292,  269,  295,  296,  298,  291,
      292,  300,  295,  296,  298,  301,  304,  300,  312,  314,
      277,  301,  304,  316,  312,  314,  318,  321,  323,  316,
      326,  328,  318,  321,  323,  330,  326,  328,  332,  334,
      336,  330,  339,  339,  332,  334,  336,  343,  347,  350,

      352,  354,  355,  356,  347,  350,  352,  354,  355,  356,
      359,  381,  339,  362,  364,  367,  359,  343,  370,  362,
      364,  367,  372,  373,  370,  375,  377,  379,  372,  373,
      382,  375,  377,  379,  383,  387,  382,  388,  391,  393,
      383,  387,  395,  388,  391,  393,  396,  397,  395,  398,
      399,  401,  396,  397,  404,  398,  399,  401,  407,  411,
      404,  413,  416,  419,  407,  411,  421,  413,  416,  419,
      423,  425,  421,  429,  430,  432,  423,  425,  433,  429,
      430,  432,  434,  435,  433,  437,  440,  442,  434,  435,
      444,  437,  440,  442,  378,  376,  444,  448,  448,  448,

      448,  448,  448,  448,  449,  449,  450,  450,  451,  451,
      451,  451,  451,  451,  451,  452,  374,  452,  452,  453,
      453,  454,  454,  455,  455,  455,  455,  455,  456,  456,
      456,  456,  456,  456,  456,  457,  457,  457,  457,  457,
      457,  457,  458,  369,  458,  458,  458,  458,  458,  459,
      459,  459,  459,  459,  459,  459,  366,  361,  358,  353,
      349,  345,  341,  338,  325,  320,  317,  311,  310,  309,
      308,  307,  306,  305,  303,  297,  294,  290,  288,  287,
      286,  285,  276,  275,  274,  272,  268,  238,  233,  229,
      228,  223,  222,  221,  220,  219,  218,  217,  216,  213,

      211,  205,  204,  203,  202,  200,  197,  196,  195,  194,
      193,  192,  186,  185,  181,  180,  179,  178,  177,  175,
      174,  172,  171,  158,  156,  155,  153,  152,  151,  148,
      144,  141,  140,  138,  137,  132,  131,  130,  129,  124,
      121,  119,  118,  116,  115,  114,  113,  112,  110,  108,
      107,  105,  104,  103,  102,  100,   99,   98,   97,   96,
       95,   94,   93,   92,   91,   88,   87,   86,   85,   82,
       78,   77,   76,   74,   73,   71,   70,   69,   65,   58,
       56,   53,   52,   48,   46,   45,   44,   41,   39,   38,
       32,   30,   26,   25,   23,   17,   14,   11,  447,  447,

      447,  447,  447,  447,  447,  447,  447,  447,  447,  447,
      447,  447,  447,  447,  447,  447,  447,  447,  447,  447,
      447,  447,  447,  447,  447,  447,  447,  447,  447,  447,
      447,  447,  447,  447,  447,  447,  447,  447,  447,  447,
      447,  447,  447,  447,  447,  447,  447,  447,  447
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
#line 2 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"

 /*
    csound_pre.l:

    Copyright (C) 2011
    John ffitch

    This file is part of Csound.

    The Csound Library is free software; you can redistribute it
    and/or modify it under the terms of the Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    Csound is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with Csound; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MAc
    02110-1301 USA
*/

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <ctype.h>
#include "csoundCore.h"
#include "corfile.h"
#include <inttypes.h>
#define YY_DECL int yylex (CSOUND *csound, yyscan_t yyscanner)
static void comment(yyscan_t);
static void do_comment(yyscan_t);
static void do_include(CSOUND *, int, yyscan_t);
static void do_new_include(CSOUND *, yyscan_t);
static void do_macro_arg(CSOUND *, char *, yyscan_t);
static void do_macro(CSOUND *, char *, yyscan_t);
static void do_umacro(CSOUND *, char *, yyscan_t);
static void do_umacroq(CSOUND *, char *, yyscan_t);
static void do_ifdef(CSOUND *, char *, yyscan_t);
static void do_ifdef_skip_code(CSOUND *, yyscan_t);
static void do_function(CSOUND*, char *, CORFIL*);
//static void print_csound_predata(CSOUND *,char *,yyscan_t);
static void csound_pre_line(CSOUND *, CORFIL*, yyscan_t);
//static void delete_macros(CSOUND*, yyscan_t);
#include "parse_param.h"

#define YY_EXTRA_TYPE  PRE_PARM *
#define PARM    yyget_extra(yyscanner)

#define YY_USER_INIT {csound_pre_scan_string(csound->orchstr->body, yyscanner); \
    csound_preset_lineno(csound->orcLineOffset, yyscanner);             \
    yyg->yy_flex_debug_r=1; PARM->macro_stack_size = 0;                 \
    PARM->alt_stack = NULL; PARM->macro_stack_ptr = 0;                  \
    PARM->path = ".";                                                   \
  }
static MACRO *find_definition(MACRO *, char *);

#define S_INC (10)

#line 1027 "Engine/csound_prelex.c"

#line 1029 "Engine/csound_prelex.c"

#define INITIAL 0
#define incl 1
#define macro 2
#define umacro 3
#define ifdef 4

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  , yyscan_t yyscanner);
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (yyscan_t yyscanner);

#define YY_DECL int yylex (yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 169 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"


#line 1296 "Engine/csound_prelex.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 448 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 447 );
		yy_cp = yyg->yy_last_accepting_cpos;
		yy_current_state = yyg->yy_last_accepting_state;

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 171 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ csound_preset_lineno(csound->orcLineOffset, yyscanner);
                  csound->Free(csound, PARM->alt_stack);
                }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 174 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                  char bb[80];
                  csound_preset_lineno(1+csound_preget_lineno(yyscanner),
                                       yyscanner);
                  if (PARM->isString==0) {
                    sprintf(bb, "#sline %d ", csound_preget_lineno(yyscanner));
                    corfile_puts(csound, bb, csound->expanded_orc);
                  }
                }
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 183 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                  corfile_putc(csound, '\n', csound->expanded_orc);
                  csound_preset_lineno(1+csound_preget_lineno(yyscanner),
                                       yyscanner);
                  csound_pre_line(csound, csound->expanded_orc, yyscanner);
                }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 189 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                  if (PARM->isString != 1) {
                    comment(yyscanner);
                    corfile_putc(csound, '\n', csound->expanded_orc);
                    csound_pre_line(csound, csound->expanded_orc, yyscanner);
                  }
                  else {
                    corfile_puts(csound, yytext, csound->expanded_orc);
                  }
                }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 199 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                  if (PARM->isString != 1) {
                    comment(yyscanner);
                    corfile_putc(csound, '\n', csound->expanded_orc);
                    csound_pre_line(csound, csound->expanded_orc, yyscanner);
                  }
                  else {
                    corfile_puts(csound, yytext, csound->expanded_orc);
                  }
                  //corfile_putline(csound_preget_lineno(yyscanner),
                  //                csound->expanded_orc);
                }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 211 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                  if (PARM->isString != 1)
                    do_comment(yyscanner);
                  else
                    corfile_puts(csound, yytext, csound->expanded_orc);
                }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 217 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ corfile_puts(csound, yytext, csound->expanded_orc); }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 218 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                  corfile_putc(csound, '"', csound->expanded_orc);
                  PARM->isString = !PARM->isString;
                  if (PARM->isinclude && PARM->isString==0) {
                    do_new_include(csound, yyscanner);
                    PARM->isinclude = 0;
                  }
                }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 226 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                  char c, *str = yytext;
                  if (PARM->isString == 1)
                    yyless(2);
                  while ((c = *str++) != '\0') {
                    switch(c) {
                    case '\r': if (*str == '\n') continue;
                    case '\n':
                      csound_preset_lineno(1+csound_preget_lineno(yyscanner),
                                           yyscanner);
                      break;
                    default: break;
                    }
                  }
                  corfile_puts(csound, yytext, csound->expanded_orc);
                }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 242 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                   MACRO     *mm = csound->orc_macros;
                   //printf("macro name >>%s<<\n", yytext);
                   mm = find_definition(mm, yytext+1);
                   if (UNLIKELY(mm == NULL)) {
                     csound->Message(csound,Str("Undefined macro: '%s'"), yytext);
                     //csound->LongJmp(csound, 1);
                     corfile_puts(csound, "$error", csound->expanded_orc);
                   }
                   else {
                     /* Need to read from macro definition */
                     if (UNLIKELY(PARM->macro_stack_ptr +1 >=
                                  PARM->macro_stack_size )) {
                       PARM->alt_stack =
                         (MACRON*)
                         csound->ReAlloc(csound, PARM->alt_stack,
                                         sizeof(MACRON)*
                                               (PARM->macro_stack_size+=S_INC));
                       if (UNLIKELY(PARM->alt_stack == NULL)) {
                         csound->Message(csound, Str("Memory exhausted"));
                         csound->LongJmp(csound, 1);
                       }
                     }
                     PARM->alt_stack[PARM->macro_stack_ptr].n = 0;
                     PARM->alt_stack[PARM->macro_stack_ptr].line =
                       csound_preget_lineno(yyscanner);
                     PARM->alt_stack[PARM->macro_stack_ptr].path = NULL;
                     PARM->alt_stack[PARM->macro_stack_ptr++].s = NULL;
                     yypush_buffer_state(YY_CURRENT_BUFFER, yyscanner);
                     csound_preset_lineno(1, yyscanner);
                     if (UNLIKELY(PARM->depth>1022)) {
                       csound->Message(csound,
                                       Str("macros/include nested too deep: "));
                       csound->LongJmp(csound, 1);
                     }
                     PARM->lstack[++PARM->depth] =
                       (strchr(mm->body,'\n') ?file_to_int(csound, yytext) : 63);
                     yy_scan_string(mm->body, yyscanner);
                     /* csound->DebugMsg(csound,"%p\n", YY_CURRENT_BUFFER); */
                   }
                }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 283 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                   MACRO     *mm = csound->orc_macros;
                   int err = 0;
                   char      *mname;
                   int c, i, j, cnt=0;
                   //csound->DebugMsg(csound,"Macro with arguments call %s\n",
                   //                 yytext);
                   yytext[yyleng-1] = '\0';
                   mm = find_definition(mm, yytext+1);
                   if (UNLIKELY(mm == NULL)) {
                     csound->Message(csound,Str("Undefined macro: '%s'"), yytext);
                     corfile_puts(csound, "$error", csound->expanded_orc);
                   }
                   else {
                     mname = yytext;
                     /* Need to read from macro definition */
                     csound->DebugMsg(csound,"Looking for %d args\n", mm->acnt);
                     for (j = 0; j < mm->acnt; j++) {
                       char  term = (j == mm->acnt - 1 ? ')' : '\'');
                       /* Compatability */
                       char  trm1 = (j == mm->acnt - 1 ? ')' : '#');
                       MACRO *nn = (MACRO*) csound->Malloc(csound, sizeof(MACRO));
                       int   size = 100;
                       if (UNLIKELY(nn == NULL)) {
                         csound->Message(csound, Str("Memory exhausted"));
                         csound->LongJmp(csound, 1);
                       }
                       nn->name = csound->Malloc(csound, strlen(mm->arg[j]) + 1);
                       if (UNLIKELY(nn->name == NULL)) {
                         csound->Message(csound, Str("Memory exhausted"));
                         csound->LongJmp(csound, 1);
                       }
                       csound->DebugMsg(csound,"Arg %d: %s\n", j+1, mm->arg[j]);
                       strcpy(nn->name, mm->arg[j]);
                       csound->Message(csound, "defining argument %s ",
                                       nn->name);
                       i = 0;
                       nn->body = (char*) csound->Malloc(csound, 100);
                       if (UNLIKELY(nn->body == NULL)) {
                         csound->Message(csound, Str("Memory exhausted"));
                         csound->LongJmp(csound, 1);
                       }
                       while (1) {
                         c = input(yyscanner);
                         if (cnt==0 && ( c==term || c==trm1)) break;
                         if (UNLIKELY(cnt==0 && c == ')')) {
                           csound->Message(csound,
                                           Str("Too few arguments to macro\n"));
                           corfile_puts(csound, "$error", csound->expanded_orc);
                           err = 1; break;
                         }
                         if (c=='(') cnt++;
                         if (c==')') cnt--;
                         if (c == '\\') {
                           int newc = input(yyscanner);
                           if (newc == ')')
                             nn->body[i++] = c;
                           c = newc;
                         }
                         if (UNLIKELY(i > 98)) {
                           csound->Message(csound,
                                           Str("Missing argument "
                                               "terminator\n%.98s"),
                                           nn->body);
                           corfile_puts(csound, "$error", csound->expanded_orc);
                           err = 1; break;
                         }
                         nn->body[i++] = c;
                         if (UNLIKELY(i >= size)) {
                           nn->body = csound->ReAlloc(csound, nn->body,
                                                      size += 100);
                           if (UNLIKELY(nn->body == NULL)) {
                             csound->Message(csound, Str("Memory exhausted"));
                             csound->LongJmp(csound, 1);
                           }
                         }
                       }
                       nn->body[i] = '\0';
                       csound->Message(csound, "as...#%s#\n", nn->body);
                       nn->acnt = 0;       /* No arguments for arguments */
                       nn->next = csound->orc_macros;
                       csound->orc_macros = nn;
                     }
                     if (!err) {
                       //csound->DebugMsg(csound,"New body: ...#%s#\n", mm->body);
                       if (UNLIKELY(PARM->macro_stack_ptr +1 >=
                                    PARM->macro_stack_size )) {
                         PARM->alt_stack =
                           (MACRON*)
                           csound->ReAlloc(csound, PARM->alt_stack,
                                           sizeof(MACRON)*
                                                 (PARM->macro_stack_size+=S_INC));
                         if (UNLIKELY(PARM->alt_stack == NULL)) {
                           csound->Message(csound, Str("Memory exhausted"));
                           csound->LongJmp(csound, 1);
                         }
                         /* csound->DebugMsg(csound, */
                         /*        "macro_stack extends alt_stack to %d long\n", */
                         /*                  PARM->macro_stack_size); */
                       }
                       PARM->alt_stack[PARM->macro_stack_ptr].n =
                         csound->orc_macros->acnt;
                       PARM->alt_stack[PARM->macro_stack_ptr].line =
                         csound_preget_lineno(yyscanner);
                       PARM->alt_stack[PARM->macro_stack_ptr].path = NULL;
                       PARM->alt_stack[PARM->macro_stack_ptr++].s = csound->orc_macros;
                       PARM->alt_stack[PARM->macro_stack_ptr].n = 0;
                       PARM->alt_stack[PARM->macro_stack_ptr].line =
                         csound_preget_lineno(yyscanner);
                       PARM->alt_stack[PARM->macro_stack_ptr].path = NULL;
                       /* printf("stacked line = %llu at %d\n", */
                       /*  csound_preget_lineno(yyscanner), */
                       /* PARM->macro_stack_ptr-1); */
                       PARM->alt_stack[PARM->macro_stack_ptr].s = NULL;
                       //csound->DebugMsg(csound,"Push %p macro stack\n",
                       //                 csound->orc_macros);
                       yypush_buffer_state(YY_CURRENT_BUFFER, yyscanner);
                       csound_preset_lineno(1, yyscanner);
                       if (UNLIKELY(PARM->depth>1022)) {
                         csound->Message(csound,
                                         Str("macros/include nested too deep: "));
                         corfile_puts(csound, "$error", csound->expanded_orc);
                         err = 1;
                       }
                     }
                     if (!err) {
                       PARM->lstack[++PARM->depth] =
                         (strchr(mm->body,'\n') ?file_to_int(csound, mname) : 63);
                       yy_scan_string(mm->body, yyscanner);
                       csound_preset_lineno(0, yyscanner); /* for Valgrind */
                     }
                   }
                 }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 416 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                  if (PARM->isString != 1)
                    PARM->isinclude = 1;
                  else
                    corfile_puts(csound, yytext, csound->expanded_orc);
                }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 422 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                  if (PARM->isString != 1)
                    BEGIN(incl);
                  else
                    corfile_puts(csound, yytext, csound->expanded_orc);
                }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 428 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
/* eat the whitespace */
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 429 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ /* got the include file name */
                  do_include(csound, yytext[0], yyscanner);
                  BEGIN(INITIAL);
                }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 433 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ corfile_putc(csound, '\0', csound->expanded_orc);
                  corfile_putc(csound, '\0', csound->expanded_orc);
                  //delete_macros(csound, yyscanner);
                  return 0;}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(incl):
case YY_STATE_EOF(macro):
case YY_STATE_EOF(umacro):
case YY_STATE_EOF(ifdef):
#line 437 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                  MACRO *x, *y=NULL;
                  int n;
                  /* csound->DebugMsg(csound,"*********Leaving buffer %p\n", */
                  /*                  YY_CURRENT_BUFFER); */
                  yypop_buffer_state(yyscanner);
                  PARM->depth--;
                  if (UNLIKELY(PARM->depth > 1024))
                    csound->Die(csound, Str("unexpected EOF!"));
                  PARM->llocn = PARM->locn; PARM->locn = make_location(PARM);
                  /* csound->DebugMsg(csound,"%s(%d): loc=%Ld; lastloc=%Ld\n", */
                  /*                  __FILE__, __LINE__, */
                  /*        PARM->llocn, PARM->locn); */
                  if ( !YY_CURRENT_BUFFER ) yyterminate();
                  csound->DebugMsg(csound,"End of input; popping to %p\n",
                          YY_CURRENT_BUFFER);
                  csound_pre_line(csound, csound->expanded_orc, yyscanner);
                  n = PARM->alt_stack[--PARM->macro_stack_ptr].n;
                  if (PARM->alt_stack[PARM->macro_stack_ptr].path) {
                    //printf("restoring path from %s to %s\n",
                    //    PARM->path, PARM->alt_stack[PARM->macro_stack_ptr].path);
                    free(PARM->path);
                    PARM->path = PARM->alt_stack[PARM->macro_stack_ptr].path;
                  }
                  /* printf("lineno on stack is %llu\n", */
                  /*        PARM->alt_stack[PARM->macro_stack_ptr].line); */
                  csound->DebugMsg(csound,"n=%d\n", n);
                  if (n!=0) {
                    /* We need to delete n macros starting with y */
                    y = PARM->alt_stack[PARM->macro_stack_ptr].s;
                    x = csound->orc_macros;
                    if (x==y) {
                      while (n>0) {
                        mfree(csound, y->name); x=y->next;
                        mfree(csound, y); y=x; n--;
                      }
                      csound->orc_macros = x;
                    }
                    else {
                      MACRO *nxt = y->next;
                      while (x->next != y) x = x->next;
                      while (n>0) {
                        nxt = y->next;
                        mfree(csound, y->name); mfree(csound, y); y=nxt; n--;
                      }
                      x->next = nxt;
                    }
                    y->next = x;
                  }
                  csound_preset_lineno(PARM->alt_stack[PARM->macro_stack_ptr].line,
                                       yyscanner);
                  csound->DebugMsg(csound, "csound_pre(%d): line now %d at %d\n",
                                   __LINE__,
                                   csound_preget_lineno(yyscanner),
                                   PARM->macro_stack_ptr);
                  csound->DebugMsg(csound,
                                   "End of input segment: macro pop %p -> %p\n",
                                   y, csound->orc_macros);
                  //csound_preset_lineno(PARM->alt_stack[PARM->macro_stack_ptr].line,
                  //                     yyscanner);
                  //print_csound_predata(csound,"Before pre_line", yyscanner);
                  csound_pre_line(csound, csound->orchstr, yyscanner);
                  //print_csound_predata(csound,"After pre_line", yyscanner);
                }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 501 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                  if (PARM->isString != 1)
                    BEGIN(macro);
                  else
                    corfile_puts(csound, yytext, csound->expanded_orc);
                }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 507 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
/* eat the whitespace */
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 508 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                  yytext[yyleng-1] = '\0';
                  csound->DebugMsg(csound,"Define macro with args %s\n",
                                      yytext);
                  /* print_csound_predata(csound, "Before do_macro_arg",
                                          yyscanner); */
                  do_umacroq(csound, yytext, yyscanner);
                  do_macro_arg(csound, yytext, yyscanner);
                  //print_csound_predata(csound,"After do_macro_arg", yyscanner);
                  BEGIN(INITIAL);
                }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 519 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                  csound->DebugMsg(csound,"Define macro %s\n", yytext);
                  /* print_csound_predata(csound,"Before do_macro", yyscanner); */
                  do_umacroq(csound, yytext, yyscanner);
                  do_macro(csound, yytext, yyscanner);
                  //print_csound_predata(csound,"After do_macro", yyscanner);
                  BEGIN(INITIAL);
                }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 527 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ csound->Message(csound,
                                  Str("Unexpected character %c(%.2x) line %d\n"),
                                  yytext[0], yytext[0],
                                  csound_preget_lineno(yyscanner));
                  csound->LongJmp(csound, 1);
                }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 533 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                  if (PARM->isString != 1)
                    BEGIN(umacro);
                  else
                    corfile_puts(csound, yytext, csound->expanded_orc);
                }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 539 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
/* eat the whitespace */
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 540 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                  csound->DebugMsg(csound,"Undefine macro %s\n", yytext);
                  do_umacro(csound, yytext, yyscanner);
                  BEGIN(INITIAL);
                }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 546 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                  if (PARM->isString != 1) {
                    PARM->isIfndef = (yytext[3] == 'n');  /* #ifdef or #ifndef */
                    csound_preset_lineno(1+csound_preget_lineno(yyscanner),
                                         yyscanner);
                    corfile_putc(csound, '\n', csound->expanded_orc);
                    csound_pre_line(csound, csound->expanded_orc, yyscanner);
                    BEGIN(ifdef);
                  }
                  else {
                    corfile_puts(csound, yytext, csound->expanded_orc);
                  }
                }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 559 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
/* eat the whitespace */
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 560 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                  do_ifdef(csound, yytext, yyscanner);
                  BEGIN(INITIAL);
                }
	YY_BREAK
case 28:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 564 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                  if (PARM->isString != 1) {
                    if (PARM->ifdefStack == NULL) {
                      csound->Message(csound, Str("#else without #if\n"));
                      csound->LongJmp(csound, 1);
                    }
                    else if (PARM->ifdefStack->isElse) {
                      csound->Message(csound, Str("#else after #else\n"));
                      csound->LongJmp(csound, 1);
                    }
                    PARM->ifdefStack->isElse = 1;
                    csound_preset_lineno(1+csound_preget_lineno(yyscanner),
                                         yyscanner);
                    corfile_putc(csound, '\n', csound->expanded_orc);
                    csound_pre_line(csound, csound->expanded_orc, yyscanner);
                    do_ifdef_skip_code(csound, yyscanner);
                  }
                  else {
                    corfile_puts(csound, yytext, csound->expanded_orc);
                  }
                }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 585 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{
                  if (PARM->isString != 1) {
                    IFDEFSTACK *pp = PARM->ifdefStack;
                    if (UNLIKELY(pp == NULL)) {
                      csound->Message(csound, Str("Unmatched #end\n"));
                      csound->LongJmp(csound, 1);
                    }
                    PARM->ifdefStack = pp->prv;
                    csound_preset_lineno(1+csound_preget_lineno(yyscanner),
                                         yyscanner);
                    corfile_putc(csound, '\n', csound->expanded_orc);
                    csound_pre_line(csound, csound->expanded_orc, yyscanner);
                    mfree(csound, pp);
                  }
                  else {
                    corfile_puts(csound, yytext, csound->expanded_orc);
                  }
}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 603 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ corfile_puts(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 604 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 605 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 606 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 607 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 608 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 609 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 610 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 611 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 612 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 613 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 614 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 615 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 616 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 617 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 618 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 619 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 620 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 621 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 622 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 623 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 624 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 625 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 626 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 627 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 628 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 629 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 630 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 631 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 632 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 633 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 634 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 635 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 636 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 637 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 638 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 639 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 640 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 641 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 642 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 643 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 644 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 645 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 646 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 647 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 648 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 649 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 650 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 651 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 652 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 653 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 654 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 655 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 656 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 657 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 658 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 659 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 660 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 661 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 662 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 663 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 664 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 665 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 666 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 667 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 668 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 669 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 670 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 671 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 672 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 673 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ do_function(csound, yytext,csound->expanded_orc); }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 675 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
{ corfile_putc(csound, yytext[0], csound->expanded_orc); }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 677 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"
ECHO;
	YY_BREAK
#line 2275 "Engine/csound_prelex.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_last_accepting_cpos;
				yy_current_state = yyg->yy_last_accepting_state;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 448 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 448 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 447);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp , yyscan_t yyscanner)
{
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = yyg->yy_n_chars + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 677 "/build/csound/src/csound-6.18.1/Engine/csound_pre.lex"

void comment(yyscan_t yyscanner)              /* Skip until nextline */
{
    char c;
    struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
    while ((c = input(yyscanner)) != '\n' && c != '\r') { /* skip */
      if (UNLIKELY((int)c == EOF || c == '\0')) {
        YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
          YY_BUFFER_EOF_PENDING;
        return;
      }
    }
    if (c == '\r' && (c = input(yyscanner)) != '\n') {
      if (LIKELY((int)c != EOF && c != '\0'))
        unput(c);
      else
        YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
          YY_BUFFER_EOF_PENDING;
    }
    csound_preset_lineno(1+csound_preget_lineno(yyscanner),yyscanner);
}

void do_comment(yyscan_t yyscanner)              /* Skip until * and / chars */
{
    int c;
    struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
 TOP:
    c = input(yyscanner);
    switch (c) {
    NL:
    case '\n':
      csound_preset_lineno(1+csound_preget_lineno(yyscanner),yyscanner);
      goto TOP;
    case '*':
    AST:
      c = input(yyscanner);
      switch (c) {
      case '*':
        goto AST;
      case '\n':
        goto NL;
      case '/':
        return;
      case EOF:
      case '\0':
        goto ERR;
      default:
        goto TOP;
      }
    case EOF:
    ERR:
      YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
        YY_BUFFER_EOF_PENDING;
      return;
    default:
      goto TOP;
    }
}
#ifndef WIN32
int isDir(char *path) {
   struct stat statbuf;
   if (stat(path, &statbuf) != 0)
       return 0;
   return S_ISDIR(statbuf.st_mode);
}
#else
int isDir(char *path) { return 0;}
#endif

void do_include(CSOUND *csound, int term, yyscan_t yyscanner)
{
    char buffer[100];
    int p=0;
    int c;
    CORFIL *cf;
    struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
    while ((c=input(yyscanner))!=term) {
      if (c=='\n' || c==EOF || c=='\0') {
        csound->Warning(csound, Str("Ill formed #include ignored"));
        return;
      }
      buffer[p] = c;
      p++;
    }
    buffer[p] = '\0';
    //printf("****buffer >>%s<<\n", buffer);
    while ((c=input(yyscanner))!='\n');
    if (UNLIKELY(PARM->depth++>=1024)) {
      csound->Die(csound, Str("Includes nested too deeply"));
    }
    csound_preset_lineno(1+csound_preget_lineno(yyscanner), yyscanner);
    csound->DebugMsg(csound,"line %d at end of #include line\n",
                     csound_preget_lineno(yyscanner));
    {
      uint8_t n = file_to_int(csound, buffer);
      char bb[128];
      PARM->lstack[PARM->depth] = n;
      sprintf(bb, "#source %"PRIu64"\n", PARM->locn = make_location(PARM));
      PARM->llocn = PARM->locn;
      corfile_puts(csound, bb, csound->expanded_orc);
    }
    csound->DebugMsg(csound,"reading included file \"%s\"\n", buffer);
    if (UNLIKELY(isDir(buffer)))
      csound->Warning(csound, Str("%s is a directory; not including"), buffer);
    if (PARM->path && buffer[0]!= DIRSEP) { // if nested included directories
      char tmp[1024];
      csound->DebugMsg(csound, "using path %s\n", PARM->path);
      strncpy(tmp, PARM->path, 1023);
      strcat(tmp, "/");
      strncat(tmp, buffer, 1022-strlen(tmp));
      if ((cf = copy_to_corefile(csound, tmp, "INCDIR", 0))==NULL)
          cf = copy_to_corefile(csound, buffer, "INCDIR", 0);
    }
    else cf = copy_to_corefile(csound, buffer, "INCDIR", 0);
    if (UNLIKELY(cf == NULL))
      csound->Die(csound,
                  Str("Cannot open #include'd file %s\n"), buffer);
    if (UNLIKELY(PARM->macro_stack_ptr +1 >= PARM->macro_stack_size )) {
      PARM->alt_stack =
        (MACRON*) csound->ReAlloc(csound, PARM->alt_stack,
                                  sizeof(MACRON)*(PARM->macro_stack_size+=S_INC));
      if (UNLIKELY(PARM->alt_stack == NULL)) {
        csound->Message(csound, Str("Memory exhausted"));
        csound->LongJmp(csound, 1);
      }
      /* csound->DebugMsg(csound, "alt_stack now %d long,\n", */
      /*                  PARM->macro_stack_size); */
    }
    csound->DebugMsg(csound,"cso_pre(%d): stacking line %d at %d\n", __LINE__,
           csound_preget_lineno(yyscanner),PARM->macro_stack_ptr);
    PARM->alt_stack[PARM->macro_stack_ptr].n = 0;
    PARM->alt_stack[PARM->macro_stack_ptr].line = csound_preget_lineno(yyscanner);
    if (strrchr(buffer,DIRSEP)) {
      PARM->alt_stack[PARM->macro_stack_ptr].path = PARM->path;
      printf("setting path from %s to ", PARM->path);
      PARM->path = strdup(buffer); /* wasteful! */
      *(strrchr(PARM->path,DIRSEP)) = '\0';
      printf("%s\n",PARM->path);
    }
    else PARM->alt_stack[PARM->macro_stack_ptr].path = NULL;
    PARM->alt_stack[PARM->macro_stack_ptr++].s = NULL;
    csound_prepush_buffer_state(YY_CURRENT_BUFFER, yyscanner);
    csound_pre_scan_string(cf->body, yyscanner);
    corfile_rm(csound, &cf);
    csound->DebugMsg(csound,"Set line number to 1\n");
    csound_preset_lineno(1, yyscanner);
}

void  do_new_include(CSOUND *csound, yyscan_t yyscanner)
{
    char buffer[128];
    CORFIL *cf = csound->expanded_orc;
    int p = cf->p-2;
    struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;

    //printf("*** in do_new_include\n");
    cf->body[p+1] = '\0';
    while (cf->body[p]!='"') p--;
    //printf("*** name is >>%s<<\n", &cf->body[p]);
    cf->body[p] = '\0';
    strncpy(buffer, &cf->body[p+1],127); buffer[127]='\0';
    cf->p = p;
    //printf("****buffer >>%s<<\n", buffer);
    while ((input(yyscanner))!='\n');
    if (UNLIKELY(PARM->depth++>=1024)) {
      csound->Die(csound, Str("Includes nested too deeply"));
    }
    csound_preset_lineno(1+csound_preget_lineno(yyscanner), yyscanner);
    csound->DebugMsg(csound,"line %d at end of #include line\n",
                     csound_preget_lineno(yyscanner));
    {
      uint8_t n = file_to_int(csound, buffer);
      char bb[128];
      PARM->lstack[PARM->depth] = n;
      sprintf(bb, "#source %"PRIu64"\n", PARM->locn = make_location(PARM));
      PARM->llocn = PARM->locn;
      corfile_puts(csound, bb, csound->expanded_orc);
    }
    csound->DebugMsg(csound,"reading included file \"%s\"\n", buffer);
    if (UNLIKELY(isDir(buffer)))
      csound->Warning(csound, Str("%s is a directory; not including"), buffer);
    if (PARM->path && buffer[0]!=DIRSEP) {
      char tmp[1024];
      strncpy(tmp, PARM->path, 1023);
      strcat(tmp, "/");
      strncat(tmp, buffer, 1022-strlen(tmp));
      cf = copy_to_corefile(csound, tmp, "INCDIR", 0);
    }
    else cf = copy_to_corefile(csound, buffer, "INCDIR", 0);
    if (UNLIKELY(cf == NULL))
      csound->Die(csound,
                  Str("Cannot open #include'd file %s\n"), buffer);
    if (UNLIKELY(PARM->macro_stack_ptr +1 >= PARM->macro_stack_size )) {
      PARM->alt_stack =
        (MACRON*) csound->ReAlloc(csound, PARM->alt_stack,
                                  sizeof(MACRON)*(PARM->macro_stack_size+=S_INC));
      if (UNLIKELY(PARM->alt_stack == NULL)) {
        csound->Message(csound, Str("Memory exhausted"));
        csound->LongJmp(csound, 1);
      }
      /* csound->DebugMsg(csound, "alt_stack now %d long,\n", */
      /*                  PARM->macro_stack_size); */
    }
    csound->DebugMsg(csound,"cso_pre(%d): stacking line %d at %d\n", __LINE__,
           csound_preget_lineno(yyscanner),PARM->macro_stack_ptr);
    PARM->alt_stack[PARM->macro_stack_ptr].n = 0;
    PARM->alt_stack[PARM->macro_stack_ptr].line = csound_preget_lineno(yyscanner);
    if (strrchr(buffer,DIRSEP)) {
      PARM->alt_stack[PARM->macro_stack_ptr].path = PARM->path;
      PARM->path = strdup(buffer); /* wasteful! */
      *(strrchr(PARM->path,DIRSEP)) = '\0';
    }
    else PARM->alt_stack[PARM->macro_stack_ptr].path = NULL;
    PARM->alt_stack[PARM->macro_stack_ptr++].s = NULL;
    csound_prepush_buffer_state(YY_CURRENT_BUFFER, yyscanner);
    csound_pre_scan_string(cf->body, yyscanner);
    corfile_rm(csound, &cf);
    csound->DebugMsg(csound,"Set line number to 1\n");
    csound_preset_lineno(1, yyscanner);
}

static inline int isNameChar(int c, int pos)
{
    c = (int) ((unsigned char) c);
    return (isalpha(c) || (pos && (c == '_' || isdigit(c))));
}

static void do_macro_arg(CSOUND *csound, char *name0, yyscan_t yyscanner)
{
    MACRO *mm = (MACRO*) csound->Malloc(csound, sizeof(MACRO));
    int   arg = 0, i, c;
    int   size = 100;
    int mlen = 40;
    char *q = name0;
    char *mname = malloc(mlen);

    if (UNLIKELY(mm == NULL)) {
      csound->Message(csound, Str("Memory exhausted"));
      csound->LongJmp(csound, 1);
    }
    mm->margs = MARGS;    /* Initial size */
    mm->name = (char*)csound->Malloc(csound, strlen(name0) + 1);
    if (UNLIKELY(mm->name == NULL)) {
      csound->Message(csound, Str("Memory exhausted"));
      csound->LongJmp(csound, 1);
    }
    strcpy(mm->name, name0);
    do {
      i = 0;
      q = name0;
      mname[i++] = '`';
      while ((c = *q++)) {
        mname[i++] = c;
        if (UNLIKELY(i==mlen))
          mname = (char *)realloc(mname, mlen+=40);
        if (UNLIKELY(mname == NULL)) {
          csound->Message(csound, Str("Memory exhausted"));
          csound->LongJmp(csound, 1);
        }
      }
      mname[i++] = '`';
      if (UNLIKELY(i==mlen)) {
        mname = (char *)realloc(mname, mlen+=40);
        if (UNLIKELY(mname == NULL)) {
          csound->Message(csound, Str("Memory exhausted"));
          csound->LongJmp(csound, 1);
        }
      }
      mname[i++] = '`';
      if (UNLIKELY(i==mlen)) {
        mname = (char *)realloc(mname, mlen+=40);
        if (UNLIKELY(mname == NULL)) {
          csound->Message(csound, Str("Memory exhausted"));
          csound->LongJmp(csound, 1);
        }
      }
      while (isspace((c = input(yyscanner))));

      while (isNameChar(c, i)) {
        mname[i++] = c;
        if (UNLIKELY(i==mlen)) {
          mname = (char *)realloc(mname, mlen+=40);
          if (UNLIKELY(mname == NULL)) {
            csound->Message(csound, Str("Memory exhausted"));
            csound->LongJmp(csound, 1);
          }
        }
        c = input(yyscanner);
      }
      mname[i] = '\0';
      mm->arg[arg] = csound->Malloc(csound, i + 1);
      if (UNLIKELY(mm->arg[arg] == NULL)) {
        csound->Message(csound, Str("Memory exhausted"));
        csound->LongJmp(csound, 1);
      }
      strcpy(mm->arg[arg++], mname);
      if (UNLIKELY(arg >= mm->margs)) {
        mm = (MACRO*) csound->ReAlloc(csound, mm, sizeof(MACRO)
                               + mm->margs * sizeof(char*));
        if (UNLIKELY(mm == NULL)) {
          csound->Message(csound, Str("Memory exhausted"));
          csound->LongJmp(csound, 1);
        }
        mm->margs += MARGS;
      }
      while (isspace(c))
        c = input(yyscanner);
    } while (c == '\'' || c == '#');
    if (UNLIKELY(c != ')')) {
      csound->Message(csound, Str("macro error\n"));
    }
    free(mname);
    c = input(yyscanner);
    while (c!='#') {
      if (UNLIKELY(c==EOF || c=='\0'))
        csound->Die(csound, Str("define macro runaway\n"));
      else if (c==';') {
        while ((c=input(yyscanner))!= '\n')
          if (UNLIKELY(c==EOF || c=='\0')) {
            csound->Die(csound, Str("define macro runaway\n"));
          }
      }
      else if (c=='/') {
        if ((c=input(yyscanner))=='/') {
          while ((c=input(yyscanner))!= '\n')
            if (UNLIKELY(c==EOF || c=='\0'))
              csound->Die(csound, Str("define macro runaway\n"));
        }
        else if (c=='*') {
          while ((c=input(yyscanner))!='*') {
          again:
            if (UNLIKELY(c==EOF || c=='\0'))
              csound->Die(csound, Str("define macro runaway\n"));
          }
          if ((c=input(yyscanner))!='/') goto again;
        }
      }
      else if (UNLIKELY(!isspace(c)))
        csound->Die(csound,
               Str("define macro unexpected character %c(0x%.2x) awaiting #\n"),
                    c, c);
      c = input(yyscanner); /* skip to start of body */
    }
    mm->acnt = arg;
    i = 0;
    mm->body = (char*) csound->Malloc(csound, 100);
    if (UNLIKELY(mm->body == NULL)) {
      csound->Message(csound, Str("Memory exhausted"));
      csound->LongJmp(csound, 1);
    }

    while ((c = input(yyscanner)) != '#') { /* read body */
      if (UNLIKELY(c == EOF || c == '\0'))
        csound->Die(csound, Str("define macro with args: unexpected EOF"));
      if (c=='$') {             /* munge macro name? */
        int n = strlen(name0)+4;
        if (UNLIKELY(i+n >= size)) {
          mm->body = csound->ReAlloc(csound, mm->body, size += 100);
          if (UNLIKELY(mm->body == NULL)) {
            csound->Message(csound, Str("Memory exhausted"));
            csound->LongJmp(csound, 1);
          }
        }
        mm->body[i] = '$'; mm->body[i+1] = '`';
        strcpy(&mm->body[i+2], name0);
        mm->body[i + n - 2] = '`'; mm->body[i + n - 1] = '`';
        i+=n;
        continue;
      }
      mm->body[i++] = c=='\r'?'\n':c;
      if (UNLIKELY(i >= size)) {
        mm->body = csound->ReAlloc(csound, mm->body, size += 100);
        if (UNLIKELY(mm->body == NULL)) {
          csound->Message(csound, Str("Memory exhausted"));
          csound->LongJmp(csound, 1);
        }
      }
      if (c == '\\') {                    /* allow escaped # */
        mm->body[i++] = c = input(yyscanner);
        if (UNLIKELY(i >= size)) {
          mm->body = csound->ReAlloc(csound, mm->body, size += 100);
          if (UNLIKELY(mm->body == NULL)) {
            csound->Message(csound, Str("Memory exhausted"));
            csound->LongJmp(csound, 1);
          }
        }
      }
      if (UNLIKELY(c == '\n' || c == '\r')) {
        csound_preset_lineno(1+csound_preget_lineno(yyscanner),yyscanner);
        corfile_putc(csound, '\n', csound->expanded_orc);
        csound_pre_line(csound, csound->expanded_orc, yyscanner);
      }
    }
    mm->body[i] = '\0';
    mm->next = csound->orc_macros;
    csound->orc_macros = mm;
}

static void do_macro(CSOUND *csound, char *name0, yyscan_t yyscanner)
{
    MACRO *mm = (MACRO*) csound->Malloc(csound, sizeof(MACRO));
    int   i, c;
    int   size = 100;
    if (UNLIKELY(mm == NULL)) {
      csound->Message(csound, Str("Memory exhausted"));
      csound->LongJmp(csound, 1);
    }

    mm->margs = MARGS;    /* Initial size */
    csound->DebugMsg(csound,"Macro definition for %s\n", name0);
    mm->name = (char*)csound->Malloc(csound, strlen(name0) + 1);
    if (UNLIKELY(mm->name == NULL)) {
      csound->Message(csound, Str("Memory exhausted"));
      csound->LongJmp(csound, 1);
    }
    strcpy(mm->name, name0);
    mm->acnt = 0;
    i = 0;
    while ((c = input(yyscanner)) != '#') {
      if (UNLIKELY(c==EOF || c=='\0'))
        csound->Die(csound, Str("define macro runaway\n"));
      else if (c==';') {
        while ((c=input(yyscanner))!= '\n')
          if (UNLIKELY(c==EOF || c=='\0')) {
            csound->Die(csound, Str("define macro runaway\n"));
          }
      }
      else if (c=='/') {
        if ((c=input(yyscanner))=='/') {
          while ((c=input(yyscanner))!= '\n')
            if (UNLIKELY(c==EOF || c=='\0'))
              csound->Die(csound, Str("define macro runaway\n"));
        }
        else if (c=='*') {
          while ((c=input(yyscanner))!='*') {
          again:
            if (UNLIKELY(c==EOF || c=='\0'))
              csound->Die(csound, Str("define macro runaway\n"));
          }
          if ((c=input(yyscanner))!='/') goto again;
        }
      }
      else if (UNLIKELY(!isspace(c)))
        csound->Die(csound,
                    Str("define macro unexpected character %c(0x%.2x)"
                        " awaiting #\n"),
                    c, c);
    }
    mm->body = (char*) csound->Malloc(csound, 100);
    if (UNLIKELY(mm->body == NULL)) {
      csound->Message(csound, Str("Memory exhausted"));
      csound->LongJmp(csound, 1);
    }
    while ((c = input(yyscanner)) != '#') {
      if (UNLIKELY(c == EOF || c=='\0'))
        csound->Die(csound, Str("define macro: unexpected EOF"));
      mm->body[i++] = c=='\r'?'\n':c;
      if (UNLIKELY(i >= size)) {
        mm->body = csound->ReAlloc(csound, mm->body, size += 100);
        if (UNLIKELY(mm->body == NULL)) {
          csound->Message(csound, Str("Memory exhausted"));
          csound->LongJmp(csound, 1);
        }
      }
      if (c == '\\') {                    /* allow escaped # */
        mm->body[i++] = c = input(yyscanner);
        if (UNLIKELY(i >= size)) {
          mm->body = csound->ReAlloc(csound, mm->body, size += 100);
          if (UNLIKELY(mm->body == NULL)) {
            csound->Message(csound, Str("Memory exhausted"));
            csound->LongJmp(csound, 1);
          }
        }
      }
      if (UNLIKELY(c == '\n' || c == '\r')) {
        csound_preset_lineno(1+csound_preget_lineno(yyscanner),yyscanner);
        corfile_putc(csound, '\n', csound->expanded_orc);
        csound_pre_line(csound, csound->expanded_orc, yyscanner);
      }
    }
    mm->body[i] = '\0';
    csound->DebugMsg(csound,"Body #%s#\n", mm->body);
    mm->next = csound->orc_macros;
    csound->orc_macros = mm;
}

static void do_umacro(CSOUND *csound, char *name0, yyscan_t yyscanner)
{
    int i,c;
    if (UNLIKELY(csound->oparms->msglevel))
      csound->Message(csound,Str("macro %s undefined\n"), name0);
    csound->DebugMsg(csound, "macro %s undefined\n", name0);
    if (strcmp(name0, csound->orc_macros->name)==0) {
      MACRO *mm=csound->orc_macros->next;
      mfree(csound, csound->orc_macros->name); mfree(csound, csound->orc_macros->body);
      for (i=0; i<csound->orc_macros->acnt; i++)
        mfree(csound, csound->orc_macros->arg[i]);
      mfree(csound, csound->orc_macros); csound->orc_macros = mm;
    }
    else {
      MACRO *mm = csound->orc_macros;
      MACRO *nn = mm->next;
      while (strcmp(name0, nn->name) != 0) {
        mm = nn; nn = nn->next;
        if (UNLIKELY(nn == NULL)) {
          csound->Message(csound, Str("Undefining undefined macro"));
          csound->LongJmp(csound, 1);
        }
      }
      mfree(csound, nn->name); mfree(csound, nn->body);
      for (i=0; i<nn->acnt; i++)
        mfree(csound, nn->arg[i]);
      mm->next = nn->next; mfree(csound, nn);
    }
    while ((c=input(yyscanner)) != '\n' &&
           c != EOF && c != '\r'); /* ignore rest of line */
    csound_preset_lineno(1+csound_preget_lineno(yyscanner),yyscanner);
}

static void do_umacroq(CSOUND *csound, char *name0, yyscan_t yyscanner)
{
    int i;
    MACRO *mm = csound->orc_macros, *last = NULL;
    while (mm) {
      if (strcmp(name0, mm->name)==0) {
        MACRO *nn=mm->next;
        mfree(csound, mm->name); mfree(csound, mm->body);
        for (i=0; i<mm->acnt; i++)
          mfree(csound, mm->arg[i]);
        mfree(csound, mm);
        if (last) last->next = nn;
        else csound->orc_macros = nn;
        return;
      }
      last = mm; mm = last->next;
    }
    return;
}

static void do_ifdef(CSOUND *csound, char *name0, yyscan_t yyscanner)
{
    int c;
    MACRO *mm;
    IFDEFSTACK *pp;
    pp = (IFDEFSTACK*) csound->Calloc(csound, sizeof(IFDEFSTACK));
    if (UNLIKELY(pp == NULL)) {
      csound->Message(csound, Str("Memory exhausted"));
      csound->LongJmp(csound, 1);
    }
    pp->prv = PARM->ifdefStack;
    pp->isDef = PARM->isIfndef;
    for (mm = csound->orc_macros; mm != NULL; mm = mm->next) {
      if (strcmp(name0, mm->name) == 0) {
        pp->isDef ^= (unsigned char) 1;
        break;
      }
    }
    PARM->ifdefStack = pp;
    pp->isSkip = pp->isDef ^ (unsigned char) 1;
    if (pp->isSkip)
      do_ifdef_skip_code(csound, yyscanner);
    else
      while ((c = input(yyscanner)) != '\n' && c != '\r' && c != EOF);
}

static void do_ifdef_skip_code(CSOUND *csound, yyscan_t yyscanner)
{
    int i, c, nested_ifdef = 0;
    char buf[8];
    IFDEFSTACK *pp;
    /* buf = (char*)malloc(8*sizeof(char)); */
    /* if (UNLIKELY(buf == NULL)) { */
    /*   csound->Message(csound, Str("Memory exhausted")); */
    /*   csound->LongJmp(csound, 1); */
    /* } */
    pp = PARM->ifdefStack;
    c = input(yyscanner);
    for (;;) {
      while (c!='\n' && c!= '\r') {
        if (UNLIKELY(c == EOF || c=='\0')) {
          csound->Message(csound, Str("Unmatched #if%sdef\n"),
                          PARM->isIfndef ? "n" : "");
          csound->LongJmp(csound, 1);
        }
        c = input(yyscanner);
      }
      csound_preset_lineno(1+csound_preget_lineno(yyscanner),
                           yyscanner);
      corfile_putc(csound, '\n', csound->expanded_orc);
      csound_pre_line(csound, csound->expanded_orc, yyscanner);
      while (isblank(c = input(yyscanner)));  /* eat the whitespace */
      if (c == '#') {
        for (i=0; islower(c = input(yyscanner)) && i < 7; i++)
          buf[i] = c;
        buf[i] = '\0';
        if (strcmp("end", buf) == 0 || strcmp("endif", buf) == 0) {
          if (nested_ifdef-- == 0) {
            PARM->ifdefStack = pp->prv;
            mfree(csound, pp);
            break;
          }
        }
        else if (strcmp("ifdef", buf) == 0 || strcmp("ifndef", buf) == 0) {
          nested_ifdef++;
        }
        else if (strcmp("else", buf) == 0 && nested_ifdef == 0) {
          if (UNLIKELY(pp->isElse)) {
            csound->Message(csound, Str("#else after #else\n"));
            csound->LongJmp(csound, 1);
          }
          pp->isElse = 1;
          break;
        }
      }
    }
    while (c != '\n' && c != EOF && c != '\r') c = input(yyscanner);
}

#if 0
static void delete_macros(CSOUND *csound, yyscan_t yyscanner)
{
    MACRO * qq = csound->orc_macros;
    if (qq) {
      MACRO *mm = qq;
      while (mm) {
        csound->Free(csound, mm->body);
        csound->Free(csound, mm->name);
        qq = mm->next;
        csound->Free(csound, mm);
        mm = qq;
       }
    }
}
#endif

static void add_math_const_macro(CSOUND *csound, char * name, char *body)
{
    MACRO *mm;

    mm = (MACRO*) csound->Calloc(csound, sizeof(MACRO));
    mm->name = (char*) csound->Calloc(csound, strlen(name) + 3);
    sprintf(mm->name, "M_%s", name);
    mm->next = csound->orc_macros;
    csound->orc_macros = mm;
    mm->margs = MARGS;    /* Initial size */
    mm->acnt = 0;
    mm->body = (char*) csound->Calloc(csound, strlen(body) + 1);
    mm->body = strcpy(mm->body, body);
}

/**
 * Add math constants from math.h as orc csound->orc_macros
 */
void cs_init_math_constants_macros(CSOUND *csound)
{
    if (csound->orc_macros == NULL) {
      add_math_const_macro(csound, "E",     "2.71828182845904523536");
      add_math_const_macro(csound, "LOG2E", "1.44269504088896340736");
      add_math_const_macro(csound, "LOG10E","0.43429448190325182765");
      add_math_const_macro(csound, "LN2",   "0.69314718055994530942");
      add_math_const_macro(csound, "LN10",  "2.30258509299404568402");
      add_math_const_macro(csound, "PI",    "3.14159265358979323846");
      add_math_const_macro(csound, "PI_2",  "1.57079632679489661923");
      add_math_const_macro(csound, "PI_4",  "0.78539816339744830962");
      add_math_const_macro(csound, "1_PI",  "0.31830988618379067154");
      add_math_const_macro(csound, "2_PI",  "0.63661977236758134308");
      add_math_const_macro(csound, "2_SQRTPI", "1.12837916709551257390");
      add_math_const_macro(csound, "SQRT2", "1.41421356237309504880");
      add_math_const_macro(csound, "SQRT1_2","0.70710678118654752440");
      add_math_const_macro(csound, "INF",   "800000000000.0");/* ~25367 years */
    }
}

void cs_init_omacros(CSOUND *csound, NAMES *nn)
{
    while (nn) {
      char  *s = nn->mac;
      char  *p = strchr(s, '=');
      char  *mname;
      MACRO *mm;

      if (p == NULL)
        p = s + strlen(s);
      if (csound->oparms->msglevel & 7)
        csound->Message(csound, Str("Macro definition for %*s\n"), (int)(p - s), s);
      s = strchr(s, ':') + 1;                   /* skip arg bit */
      if (UNLIKELY(s == NULL || s >= p)) {
        csound->Die(csound, Str("Invalid macro name for --omacro"));
      }
      mname = (char*) csound->Malloc(csound, (p - s) + 1);
      if (UNLIKELY(mname == NULL)) {
        csound->Message(csound, Str("Memory exhausted"));
        csound->LongJmp(csound, 1);
      }
      strncpy(mname, s, p - s);
      mname[p - s] = '\0';
      /* check if macro is already defined */
      for (mm = csound->orc_macros; mm != NULL; mm = mm->next) {
        if (strcmp(mm->name, mname) == 0)
          break;
      }
      if (mm == NULL) {
        mm = (MACRO*) csound->Calloc(csound, sizeof(MACRO));
        if (UNLIKELY(mm  == NULL)) {
          csound->Message(csound, Str("Memory exhausted"));
          csound->LongJmp(csound, 1);
        }
        mm->name = mname;
        mm->next = csound->orc_macros;
        csound->orc_macros = mm;
      }
      else
        mfree(csound, mname);
      mm->margs = MARGS;    /* Initial size */
      mm->acnt = 0;
      if (*p != '\0')
        p++;
      mm->body = (char*) csound->Malloc(csound, strlen(p) + 1);
      if (UNLIKELY(mm->body == NULL)) {
        csound->Message(csound, Str("Memory exhausted"));
        csound->LongJmp(csound, 1);
      }
      strcpy(mm->body, p);
      nn = nn->next;
    }
}

/* int csound_prewrap(void *yyscanner)  */
/* {  */
/*     return 1; */
/* } */

void csound_pre_line(CSOUND *csound, CORFIL* cf, void *yyscanner)
{
    int n = csound_preget_lineno(yyscanner);
    //printf("line number %d\n", n);
    /* This assumes that the initial line was not written with this system  */
    if (cf->p>0 && cf->body[cf->p-1]=='\n') {
      uint64_t locn = PARM->locn;
      uint64_t llocn = PARM->llocn;
      if (UNLIKELY(locn != llocn)) {
        char bb[80];
        sprintf(bb, "#source %"PRIu64"\n", locn);
        corfile_puts(csound, bb, cf);
      }
      PARM->llocn = locn;
      if (UNLIKELY(n!=PARM->line+1)) {
        char bb[80];
        sprintf(bb, "#line   %d\n", n);
        corfile_puts(csound, bb, cf);
      }
    }
    PARM->line = n;
}

void do_function(CSOUND *csound, char *text, CORFIL *cf)
{
    char *p = text;
    //printf("do_function on >>%s<<\n", text);
    while (*p != '\0') {
      if (!isspace(*p)) corfile_putc(csound, *p, cf);
      p++;
    }
    return;
}

static MACRO *find_definition(MACRO *mmo, char *s)
{
    MACRO *mm = mmo;
    if (s[strlen(s)-1]=='.') s[strlen(s)-1]='\0';
    else if (s[strlen(s)-2]=='.' && s[strlen(s)-1]=='(') {
      s[strlen(s)-2] = '('; s[strlen(s)-1] = '\0'; }
    // printf("****Looking for %s strlen=%d\n", s, strlen(s), s[strlen(s)-1]);
    while (mm != NULL) {  /* Find the definition */
      //printf("looking at %p(%s) body #%s#\n", mm, mm->name, mm->body);
      if (!(strcmp(s, mm->name))) break;
      mm = mm->next;
    }
    if (mm == NULL) {
      mm = mmo;
      s++;                      /* skip _ */
    looking:
      while (*s++!='`') { if (*s=='\0') return NULL; }
      if (*s++!='`') { s--; goto looking; }
      //printf("now try looking for %s\n", s);
      while (mm != NULL) {  /* Find the definition */
        //printf("looking at %p(%s) body #%s#\n", mm, mm->name, mm->body);
        if (!(strcmp(s, mm->name))) break;
        mm = mm->next;
      }
    }
    //if (mm) printf("found body #%s#\n****\n", mm->body);
    return mm;
}


#if 0
static void print_csound_predata(CSOUND *csound, char *mesg, void *yyscanner)
{
    struct yyguts_t *yyg =(struct yyguts_t*)yyscanner;
    csound->DebugMsg(csound,"********* %s extra data ************", mesg);
    csound->DebugMsg(csound,"yyscanner = %p", yyscanner);
    csound->DebugMsg(csound,"yyextra_r = %p, yyin_r = %p, yyout_r = %p,"
                     " yy_buffer_stack_top = %d",
           yyg->yyextra_r, yyg->yyin_r,yyg->yyout_r, yyg->yy_buffer_stack_top);
    csound->DebugMsg(csound,"yy_buffer_stack_max = %d1, yy_buffer_stack = %p, "
                     "yy_hold_char = %d '%c'",
           yyg->yy_buffer_stack_max, yyg->yy_buffer_stack, yyg->yy_hold_char,
           yyg->yy_hold_char);
    csound->DebugMsg(csound,"yy_n_chars = %d, yyleng_r = %d, yy_c_buf_p = %p %c",
           yyg->yy_n_chars, yyg->yyleng_r, yyg->yy_c_buf_p, *yyg->yy_c_buf_p);
    csound->DebugMsg(csound,"yy_init = %d, yy_start = %d, "
                     "yy_did_buffer_switch_on_eof = %d",
           yyg->yy_init, yyg->yy_start, yyg->yy_did_buffer_switch_on_eof);
    csound->DebugMsg(csound,"yy_start_stack_ptr = %d,"
                     " yy_start_stack_depth = %d, yy_start_stack = %p",
           yyg->yy_start_stack_ptr, yyg->yy_start_stack_depth, yyg->yy_start_stack);

    csound->DebugMsg(csound,"yy_last_accepting_state = %d, "
                     "yy_last_accepting_cpos = %p %c",
           yyg->yy_last_accepting_state, yyg->yy_last_accepting_cpos,
                     *yyg->yy_last_accepting_cpos);
    csound->DebugMsg(csound,"yylineno_r = %d, yy_flex_debug_r = %d, "
                     "yytext_r = %p \"%s\", yy_more_flag = %d, yy_more_len = %d",
           yyg->yylineno_r, yyg->yy_flex_debug_r, yyg->yytext_r, yyg->yytext_r,
                     yyg->yy_more_flag, yyg->yy_more_len);
    {
      PRE_PARM* pp = yyg->yyextra_r;
      printf("macros = %p, isIfndef = %d, isString = %d, line - %d loc = %d\n",
             pp->macros, pp->isIfndef, pp->isString, pp->line, pp->locn);
      printf
        ("llocn = %d dept=%d\n", pp->llocn, pp->depth);
    }
    csound->DebugMsg(csound,"*********\n");
}
#endif

